package javax.swing.plaf.basic;

import sun.swing.SwingUtilities2;
import java.awt.KeyboardFocusManager;
import java.awt.FocusTraversalPolicy;
import sun.swing.UIAction;
import java.awt.Container;
import java.awt.LayoutManager2;
import java.awt.event.ActionEvent;
import java.awt.event.FocusEvent;
import java.awt.event.FocusAdapter;
import java.beans.PropertyChangeEvent;
import java.awt.peer.ComponentPeer;
import java.awt.peer.LightweightPeer;
import java.awt.Insets;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Canvas;
import sun.swing.DefaultLookup;
import javax.swing.InputMap;
import javax.swing.SwingUtilities;
import javax.swing.border.Border;
import java.util.HashSet;
import javax.swing.UIManager;
import javax.swing.plaf.UIResource;
import javax.swing.LookAndFeel;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.awt.Color;
import java.awt.event.ActionListener;
import java.awt.Component;
import javax.swing.KeyStroke;
import java.util.Set;
import java.awt.event.FocusListener;
import java.beans.PropertyChangeListener;
import javax.swing.JSplitPane;
import javax.swing.plaf.SplitPaneUI;

public class BasicSplitPaneUI extends SplitPaneUI
{
    protected static final String NON_CONTINUOUS_DIVIDER = "nonContinuousDivider";
    protected static int KEYBOARD_DIVIDER_MOVE_OFFSET;
    protected JSplitPane splitPane;
    protected BasicSplitPaneUI.BasicHorizontalLayoutManager layoutManager;
    protected BasicSplitPaneDivider divider;
    protected PropertyChangeListener propertyChangeListener;
    protected FocusListener focusListener;
    private BasicSplitPaneUI.Handler handler;
    private Set<KeyStroke> managingFocusForwardTraversalKeys;
    private Set<KeyStroke> managingFocusBackwardTraversalKeys;
    protected int dividerSize;
    protected Component nonContinuousLayoutDivider;
    protected boolean draggingHW;
    protected int beginDragDividerLocation;
    @Deprecated
    protected KeyStroke upKey;
    @Deprecated
    protected KeyStroke downKey;
    @Deprecated
    protected KeyStroke leftKey;
    @Deprecated
    protected KeyStroke rightKey;
    @Deprecated
    protected KeyStroke homeKey;
    @Deprecated
    protected KeyStroke endKey;
    @Deprecated
    protected KeyStroke dividerResizeToggleKey;
    @Deprecated
    protected ActionListener keyboardUpLeftListener;
    @Deprecated
    protected ActionListener keyboardDownRightListener;
    @Deprecated
    protected ActionListener keyboardHomeListener;
    @Deprecated
    protected ActionListener keyboardEndListener;
    @Deprecated
    protected ActionListener keyboardResizeToggleListener;
    private int orientation;
    private int lastDragLocation;
    private boolean continuousLayout;
    private boolean dividerKeyboardResize;
    private boolean dividerLocationIsSet;
    private Color dividerDraggingColor;
    private boolean rememberPaneSizes;
    private boolean keepHidden;
    boolean painted;
    boolean ignoreDividerLocationChange;
    
    public BasicSplitPaneUI() {
        this.keepHidden = false;
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new BasicSplitPaneUI();
    }
    
    static void loadActionMap(LazyActionMap lazyActionMap) {
        lazyActionMap.put(new BasicSplitPaneUI.Actions("negativeIncrement"));
        lazyActionMap.put(new BasicSplitPaneUI.Actions("positiveIncrement"));
        lazyActionMap.put(new BasicSplitPaneUI.Actions("selectMin"));
        lazyActionMap.put(new BasicSplitPaneUI.Actions("selectMax"));
        lazyActionMap.put(new BasicSplitPaneUI.Actions("startResize"));
        lazyActionMap.put(new BasicSplitPaneUI.Actions("toggleFocus"));
        lazyActionMap.put(new BasicSplitPaneUI.Actions("focusOutForward"));
        lazyActionMap.put(new BasicSplitPaneUI.Actions("focusOutBackward"));
    }
    
    @Override
    public void installUI(JComponent component) {
        this.splitPane = (JSplitPane)component;
        this.dividerLocationIsSet = false;
        this.dividerKeyboardResize = false;
        this.keepHidden = false;
        this.installDefaults();
        this.installListeners();
        this.installKeyboardActions();
        this.setLastDragLocation(-1);
    }
    
    protected void installDefaults() {
        LookAndFeel.installBorder(this.splitPane, "SplitPane.border");
        LookAndFeel.installColors(this.splitPane, "SplitPane.background", "SplitPane.foreground");
        LookAndFeel.installProperty(this.splitPane, "opaque", Boolean.TRUE);
        if (this.divider == null) {
            this.divider = this.createDefaultDivider();
        }
        this.divider.setBasicSplitPaneUI(this);
        Border border = this.divider.getBorder();
        if (border == null || !(border instanceof UIResource)) {
            this.divider.setBorder(UIManager.getBorder("SplitPaneDivider.border"));
        }
        this.dividerDraggingColor = UIManager.getColor("SplitPaneDivider.draggingColor");
        this.setOrientation(this.splitPane.getOrientation());
        Integer n = (Integer)UIManager.get("SplitPane.dividerSize");
        LookAndFeel.installProperty(this.splitPane, "dividerSize", Integer.valueOf((n == null) ? 10 : ((int)n)));
        this.divider.setDividerSize(this.splitPane.getDividerSize());
        this.dividerSize = this.divider.getDividerSize();
        this.splitPane.add(this.divider, "divider");
        this.setContinuousLayout(this.splitPane.isContinuousLayout());
        this.resetLayoutManager();
        if (this.nonContinuousLayoutDivider == null) {
            this.setNonContinuousLayoutDivider(this.createDefaultNonContinuousLayoutDivider(), true);
        }
        else {
            this.setNonContinuousLayoutDivider(this.nonContinuousLayoutDivider, true);
        }
        if (this.managingFocusForwardTraversalKeys == null) {
            (this.managingFocusForwardTraversalKeys = new HashSet()).add(KeyStroke.getKeyStroke(9, 0));
        }
        this.splitPane.setFocusTraversalKeys(0, this.managingFocusForwardTraversalKeys);
        if (this.managingFocusBackwardTraversalKeys == null) {
            (this.managingFocusBackwardTraversalKeys = new HashSet()).add(KeyStroke.getKeyStroke(9, 1));
        }
        this.splitPane.setFocusTraversalKeys(1, this.managingFocusBackwardTraversalKeys);
    }
    
    protected void installListeners() {
        PropertyChangeListener propertyChangeListener = this.createPropertyChangeListener();
        this.propertyChangeListener = propertyChangeListener;
        if (propertyChangeListener != null) {
            this.splitPane.addPropertyChangeListener(this.propertyChangeListener);
        }
        if ((this.focusListener = this.createFocusListener()) != null) {
            this.splitPane.addFocusListener(this.focusListener);
        }
    }
    
    protected void installKeyboardActions() {
        SwingUtilities.replaceUIInputMap(this.splitPane, 1, this.getInputMap(1));
        LazyActionMap.installLazyActionMap(this.splitPane, BasicSplitPaneUI.class, "SplitPane.actionMap");
    }
    
    InputMap getInputMap(int n) {
        if (n == 1) {
            return (InputMap)DefaultLookup.get(this.splitPane, this, "SplitPane.ancestorInputMap");
        }
        return null;
    }
    
    @Override
    public void uninstallUI(JComponent component) {
        this.uninstallKeyboardActions();
        this.uninstallListeners();
        this.uninstallDefaults();
        this.dividerLocationIsSet = false;
        this.dividerKeyboardResize = false;
        this.splitPane = null;
    }
    
    protected void uninstallDefaults() {
        if (this.splitPane.getLayout() == this.layoutManager) {
            this.splitPane.setLayout(null);
        }
        if (this.nonContinuousLayoutDivider != null) {
            this.splitPane.remove(this.nonContinuousLayoutDivider);
        }
        LookAndFeel.uninstallBorder(this.splitPane);
        if ((this.divider.getBorder() instanceof UIResource)) {
            this.divider.setBorder(null);
        }
        this.splitPane.remove(this.divider);
        this.divider.setBasicSplitPaneUI(null);
        this.layoutManager = null;
        this.divider = null;
        this.setNonContinuousLayoutDivider(this.nonContinuousLayoutDivider = null);
        this.splitPane.setFocusTraversalKeys(0, null);
        this.splitPane.setFocusTraversalKeys(1, null);
    }
    
    protected void uninstallListeners() {
        if (this.propertyChangeListener != null) {
            this.splitPane.removePropertyChangeListener(this.propertyChangeListener);
            this.propertyChangeListener = null;
        }
        if (this.focusListener != null) {
            this.splitPane.removeFocusListener(this.focusListener);
            this.focusListener = null;
        }
        this.keyboardUpLeftListener = null;
        this.keyboardDownRightListener = null;
        this.keyboardHomeListener = null;
        this.keyboardEndListener = null;
        this.keyboardResizeToggleListener = null;
        this.handler = null;
    }
    
    protected void uninstallKeyboardActions() {
        SwingUtilities.replaceUIActionMap(this.splitPane, null);
        SwingUtilities.replaceUIInputMap(this.splitPane, 1, null);
    }
    
    protected PropertyChangeListener createPropertyChangeListener() {
        return this.getHandler();
    }
    
    private BasicSplitPaneUI.Handler getHandler() {
        if (this.handler == null) {
            this.handler = new BasicSplitPaneUI.Handler();
        }
        return this.handler;
    }
    
    protected FocusListener createFocusListener() {
        return this.getHandler();
    }
    
    @Deprecated
    protected ActionListener createKeyboardUpLeftListener() {
        return new BasicSplitPaneUI.KeyboardUpLeftHandler();
    }
    
    @Deprecated
    protected ActionListener createKeyboardDownRightListener() {
        return new BasicSplitPaneUI.KeyboardDownRightHandler();
    }
    
    @Deprecated
    protected ActionListener createKeyboardHomeListener() {
        return new BasicSplitPaneUI.KeyboardHomeHandler();
    }
    
    @Deprecated
    protected ActionListener createKeyboardEndListener() {
        return new BasicSplitPaneUI.KeyboardEndHandler();
    }
    
    @Deprecated
    protected ActionListener createKeyboardResizeToggleListener() {
        return new BasicSplitPaneUI.KeyboardResizeToggleHandler();
    }
    
    public int getOrientation() {
        return this.orientation;
    }
    
    public void setOrientation(int orientation) {
        this.orientation = orientation;
    }
    
    public boolean isContinuousLayout() {
        return this.continuousLayout;
    }
    
    public void setContinuousLayout(boolean continuousLayout) {
        this.continuousLayout = continuousLayout;
    }
    
    public int getLastDragLocation() {
        return this.lastDragLocation;
    }
    
    public void setLastDragLocation(int lastDragLocation) {
        this.lastDragLocation = lastDragLocation;
    }
    
    int getKeyboardMoveIncrement() {
        return 3;
    }
    
    public BasicSplitPaneDivider getDivider() {
        return this.divider;
    }
    
    protected Component createDefaultNonContinuousLayoutDivider() {
        return new Canvas() {
            @Override
            public void paint(Graphics graphics) {
                if (!BasicSplitPaneUI.this.isContinuousLayout() && BasicSplitPaneUI.this.getLastDragLocation() != -1) {
                    Dimension size = BasicSplitPaneUI.this.splitPane.getSize();
                    graphics.setColor(BasicSplitPaneUI.this.dividerDraggingColor);
                    if (BasicSplitPaneUI.this.orientation == 1) {
                        graphics.fillRect(0, 0, BasicSplitPaneUI.this.dividerSize - 1, size.height - 1);
                    }
                    else {
                        graphics.fillRect(0, 0, size.width - 1, BasicSplitPaneUI.this.dividerSize - 1);
                    }
                }
            }
        };
    }
    
    protected void setNonContinuousLayoutDivider(Component component) {
        this.setNonContinuousLayoutDivider(component, true);
    }
    
    protected void setNonContinuousLayoutDivider(Component nonContinuousLayoutDivider, boolean rememberPaneSizes) {
        this.rememberPaneSizes = rememberPaneSizes;
        if (this.nonContinuousLayoutDivider != null && this.splitPane != null) {
            this.splitPane.remove(this.nonContinuousLayoutDivider);
        }
        this.nonContinuousLayoutDivider = nonContinuousLayoutDivider;
    }
    
    private void addHeavyweightDivider() {
        if (this.nonContinuousLayoutDivider != null && this.splitPane != null) {
            Component leftComponent = this.splitPane.getLeftComponent();
            Component rightComponent = this.splitPane.getRightComponent();
            int dividerLocation = this.splitPane.getDividerLocation();
            if (leftComponent != null) {
                this.splitPane.setLeftComponent(null);
            }
            if (rightComponent != null) {
                this.splitPane.setRightComponent(null);
            }
            this.splitPane.remove(this.divider);
            this.splitPane.add(this.nonContinuousLayoutDivider, "nonContinuousDivider", this.splitPane.getComponentCount());
            this.splitPane.setLeftComponent(leftComponent);
            this.splitPane.setRightComponent(rightComponent);
            this.splitPane.add(this.divider, "divider");
            if (this.rememberPaneSizes) {
                this.splitPane.setDividerLocation(dividerLocation);
            }
        }
    }
    
    public Component getNonContinuousLayoutDivider() {
        return this.nonContinuousLayoutDivider;
    }
    
    public JSplitPane getSplitPane() {
        return this.splitPane;
    }
    
    public BasicSplitPaneDivider createDefaultDivider() {
        return new BasicSplitPaneDivider(this);
    }
    
    @Override
    public void resetToPreferredSizes(JSplitPane splitPane) {
        if (this.splitPane != null) {
            this.layoutManager.resetToPreferredSizes();
            this.splitPane.revalidate();
            this.splitPane.repaint();
        }
    }
    
    @Override
    public void setDividerLocation(JSplitPane splitPane, int n) {
        if (!this.ignoreDividerLocationChange) {
            this.dividerLocationIsSet = true;
            this.splitPane.revalidate();
            this.splitPane.repaint();
            if (this.keepHidden) {
                Insets insets = this.splitPane.getInsets();
                int orientation = this.splitPane.getOrientation();
                if ((orientation == 0 && n != insets.top && n != this.splitPane.getHeight() - this.divider.getHeight() - insets.top) || (orientation == 1 && n != insets.left && n != this.splitPane.getWidth() - this.divider.getWidth() - insets.left)) {
                    this.setKeepHidden(false);
                }
            }
        }
        else {
            this.ignoreDividerLocationChange = false;
        }
    }
    
    @Override
    public int getDividerLocation(JSplitPane splitPane) {
        if (this.orientation == 1) {
            return this.divider.getLocation().x;
        }
        return this.divider.getLocation().y;
    }
    
    @Override
    public int getMinimumDividerLocation(JSplitPane splitPane) {
        int n = 0;
        Component leftComponent = this.splitPane.getLeftComponent();
        if (leftComponent != null && leftComponent.isVisible()) {
            Insets insets = this.splitPane.getInsets();
            Dimension minimumSize = leftComponent.getMinimumSize();
            if (this.orientation == 1) {
                n = minimumSize.width;
            }
            else {
                n = minimumSize.height;
            }
            if (insets != null) {
                if (this.orientation == 1) {
                    n += insets.left;
                }
                else {
                    n += insets.top;
                }
            }
        }
        return n;
    }
    
    @Override
    public int getMaximumDividerLocation(JSplitPane splitPane) {
        Dimension size = this.splitPane.getSize();
        int b = 0;
        Component rightComponent = this.splitPane.getRightComponent();
        if (rightComponent != null) {
            Insets insets = this.splitPane.getInsets();
            Dimension minimumSize = new Dimension(0, 0);
            if (rightComponent.isVisible()) {
                minimumSize = rightComponent.getMinimumSize();
            }
            int n;
            if (this.orientation == 1) {
                n = size.width - minimumSize.width;
            }
            else {
                n = size.height - minimumSize.height;
            }
            b = n - this.dividerSize;
            if (insets != null) {
                if (this.orientation == 1) {
                    b -= insets.right;
                }
                else {
                    b -= insets.top;
                }
            }
        }
        return Math.max(this.getMinimumDividerLocation(this.splitPane), b);
    }
    
    @Override
    public void finishedPaintingChildren(JSplitPane splitPane, Graphics graphics) {
        if (splitPane == this.splitPane && this.getLastDragLocation() != -1 && !this.isContinuousLayout() && !this.draggingHW) {
            Dimension size = this.splitPane.getSize();
            graphics.setColor(this.dividerDraggingColor);
            if (this.orientation == 1) {
                graphics.fillRect(this.getLastDragLocation(), 0, this.dividerSize - 1, size.height - 1);
            }
            else {
                graphics.fillRect(0, this.lastDragLocation, size.width - 1, this.dividerSize - 1);
            }
        }
    }
    
    @Override
    public void paint(Graphics graphics, JComponent component) {
        if (!this.painted && this.splitPane.getDividerLocation() < 0) {
            this.ignoreDividerLocationChange = true;
            this.splitPane.setDividerLocation(this.getDividerLocation(this.splitPane));
        }
        this.painted = true;
    }
    
    @Override
    public Dimension getPreferredSize(JComponent component) {
        if (this.splitPane != null) {
            return this.layoutManager.preferredLayoutSize(this.splitPane);
        }
        return new Dimension(0, 0);
    }
    
    @Override
    public Dimension getMinimumSize(JComponent component) {
        if (this.splitPane != null) {
            return this.layoutManager.minimumLayoutSize(this.splitPane);
        }
        return new Dimension(0, 0);
    }
    
    @Override
    public Dimension getMaximumSize(JComponent component) {
        if (this.splitPane != null) {
            return this.layoutManager.maximumLayoutSize(this.splitPane);
        }
        return new Dimension(0, 0);
    }
    
    public Insets getInsets(JComponent component) {
        return null;
    }
    
    protected void resetLayoutManager() {
        if (this.orientation == 1) {
            this.layoutManager = new BasicSplitPaneUI.BasicHorizontalLayoutManager(0);
        }
        else {
            this.layoutManager = new BasicSplitPaneUI.BasicHorizontalLayoutManager(1);
        }
        this.splitPane.setLayout(this.layoutManager);
        this.layoutManager.updateComponents();
        this.splitPane.revalidate();
        this.splitPane.repaint();
    }
    
    void setKeepHidden(boolean keepHidden) {
        this.keepHidden = keepHidden;
    }
    
    private boolean getKeepHidden() {
        return this.keepHidden;
    }
    
    protected void startDragging() {
        Component leftComponent = this.splitPane.getLeftComponent();
        Component rightComponent = this.splitPane.getRightComponent();
        this.beginDragDividerLocation = this.getDividerLocation(this.splitPane);
        this.draggingHW = false;
        ComponentPeer peer;
        if (leftComponent != null && (peer = leftComponent.getPeer()) != null && !(peer instanceof LightweightPeer)) {
            this.draggingHW = true;
        }
        else {
            ComponentPeer peer2;
            if (rightComponent != null && (peer2 = rightComponent.getPeer()) != null && !(peer2 instanceof LightweightPeer)) {
                this.draggingHW = true;
            }
        }
        if (this.orientation == 1) {
            this.setLastDragLocation(this.divider.getBounds().x);
            this.dividerSize = this.divider.getSize().width;
            if (!this.isContinuousLayout() && this.draggingHW) {
                this.nonContinuousLayoutDivider.setBounds(this.getLastDragLocation(), 0, this.dividerSize, this.splitPane.getHeight());
                this.addHeavyweightDivider();
            }
        }
        else {
            this.setLastDragLocation(this.divider.getBounds().y);
            this.dividerSize = this.divider.getSize().height;
            if (!this.isContinuousLayout() && this.draggingHW) {
                this.nonContinuousLayoutDivider.setBounds(0, this.getLastDragLocation(), this.splitPane.getWidth(), this.dividerSize);
                this.addHeavyweightDivider();
            }
        }
    }
    
    protected void dragDividerTo(int lastDragLocation) {
        if (this.getLastDragLocation() != lastDragLocation) {
            if (this.isContinuousLayout()) {
                this.splitPane.setDividerLocation(lastDragLocation);
                this.setLastDragLocation(lastDragLocation);
            }
            else {
                int lastDragLocation2 = this.getLastDragLocation();
                this.setLastDragLocation(lastDragLocation);
                if (this.orientation == 1) {
                    if (this.draggingHW) {
                        this.nonContinuousLayoutDivider.setLocation(this.getLastDragLocation(), 0);
                    }
                    else {
                        int height = this.splitPane.getHeight();
                        this.splitPane.repaint(lastDragLocation2, 0, this.dividerSize, height);
                        this.splitPane.repaint(lastDragLocation, 0, this.dividerSize, height);
                    }
                }
                else if (this.draggingHW) {
                    this.nonContinuousLayoutDivider.setLocation(0, this.getLastDragLocation());
                }
                else {
                    int width = this.splitPane.getWidth();
                    this.splitPane.repaint(0, lastDragLocation2, width, this.dividerSize);
                    this.splitPane.repaint(0, lastDragLocation, width, this.dividerSize);
                }
            }
        }
    }
    
    protected void finishDraggingTo(int dividerLocation) {
        this.dragDividerTo(dividerLocation);
        this.setLastDragLocation(-1);
        if (!this.isContinuousLayout()) {
            this.splitPane.getLeftComponent().getBounds();
            if (this.draggingHW) {
                if (this.orientation == 1) {
                    this.nonContinuousLayoutDivider.setLocation(-this.dividerSize, 0);
                }
                else {
                    this.nonContinuousLayoutDivider.setLocation(0, -this.dividerSize);
                }
                this.splitPane.remove(this.nonContinuousLayoutDivider);
            }
            this.splitPane.setDividerLocation(dividerLocation);
        }
    }
    
    @Deprecated
    protected int getDividerBorderSize() {
        return 1;
    }
    
    static BasicSplitPaneUI.Handler access$100(BasicSplitPaneUI basicSplitPaneUI) {
        return basicSplitPaneUI.getHandler();
    }
    
    static boolean access$600(BasicSplitPaneUI basicSplitPaneUI) {
        return basicSplitPaneUI.getKeepHidden();
    }
    
    static {
        BasicSplitPaneUI.KEYBOARD_DIVIDER_MOVE_OFFSET = 3;
    }
    
    public class PropertyHandler implements PropertyChangeListener
    {
        @Override
        public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
            BasicSplitPaneUI.access$100(BasicSplitPaneUI.this).propertyChange(propertyChangeEvent);
        }
    }
    
    public class FocusHandler extends FocusAdapter
    {
        @Override
        public void focusGained(FocusEvent focusEvent) {
            BasicSplitPaneUI.access$100(BasicSplitPaneUI.this).focusGained(focusEvent);
        }
        
        @Override
        public void focusLost(FocusEvent focusEvent) {
            BasicSplitPaneUI.access$100(BasicSplitPaneUI.this).focusLost(focusEvent);
        }
    }
    
    public class KeyboardUpLeftHandler implements ActionListener
    {
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            if (BasicSplitPaneUI.this.dividerKeyboardResize) {
                BasicSplitPaneUI.this.splitPane.setDividerLocation(Math.max(0, BasicSplitPaneUI.this.getDividerLocation(BasicSplitPaneUI.this.splitPane) - BasicSplitPaneUI.this.getKeyboardMoveIncrement()));
            }
        }
    }
    
    public class KeyboardDownRightHandler implements ActionListener
    {
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            if (BasicSplitPaneUI.this.dividerKeyboardResize) {
                BasicSplitPaneUI.this.splitPane.setDividerLocation(BasicSplitPaneUI.this.getDividerLocation(BasicSplitPaneUI.this.splitPane) + BasicSplitPaneUI.this.getKeyboardMoveIncrement());
            }
        }
    }
    
    public class KeyboardHomeHandler implements ActionListener
    {
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            if (BasicSplitPaneUI.this.dividerKeyboardResize) {
                BasicSplitPaneUI.this.splitPane.setDividerLocation(0);
            }
        }
    }
    
    public class KeyboardEndHandler implements ActionListener
    {
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            if (BasicSplitPaneUI.this.dividerKeyboardResize) {
                Insets insets = BasicSplitPaneUI.this.splitPane.getInsets();
                int n = (insets != null) ? insets.bottom : 0;
                int n2 = (insets != null) ? insets.right : 0;
                if (BasicSplitPaneUI.this.orientation == 0) {
                    BasicSplitPaneUI.this.splitPane.setDividerLocation(BasicSplitPaneUI.this.splitPane.getHeight() - n);
                }
                else {
                    BasicSplitPaneUI.this.splitPane.setDividerLocation(BasicSplitPaneUI.this.splitPane.getWidth() - n2);
                }
            }
        }
    }
    
    public class KeyboardResizeToggleHandler implements ActionListener
    {
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            if (!BasicSplitPaneUI.this.dividerKeyboardResize) {
                BasicSplitPaneUI.this.splitPane.requestFocus();
            }
        }
    }
    
    public class BasicHorizontalLayoutManager implements LayoutManager2
    {
        protected int[] sizes;
        protected Component[] components;
        private int lastSplitPaneSize;
        private boolean doReset;
        private int axis;
        
        BasicHorizontalLayoutManager(BasicSplitPaneUI basicSplitPaneUI) {
            this(basicSplitPaneUI, 0);
        }
        
        BasicHorizontalLayoutManager(int axis) {
            this.axis = axis;
            this.components = new Component[3];
            Component[] components = this.components;
            int n = 0;
            Component[] components2 = this.components;
            int n2 = 1;
            Component[] components3 = this.components;
            int n3 = 2;
            Component component = null;
            components3[n3] = component;
            components[n] = (components2[n2] = component);
            this.sizes = new int[3];
        }
        
        @Override
        public void layoutContainer(Container container) {
            Dimension size = container.getSize();
            if (size.height <= 0 || size.width <= 0) {
                this.lastSplitPaneSize = 0;
                return;
            }
            int dividerLocation = BasicSplitPaneUI.this.splitPane.getDividerLocation();
            Insets insets = BasicSplitPaneUI.this.splitPane.getInsets();
            int availableSize = this.getAvailableSize(size, insets);
            this.getSizeForPrimaryAxis(size);
            BasicSplitPaneUI.this.getDividerLocation(BasicSplitPaneUI.this.splitPane);
            int sizeForPrimaryAxis = this.getSizeForPrimaryAxis(insets, true);
            Dimension dimension = (this.components[2] == null) ? null : this.components[2].getPreferredSize();
            if ((this.doReset && !BasicSplitPaneUI.this.dividerLocationIsSet) || dividerLocation < 0) {
                this.resetToPreferredSizes(availableSize);
            }
            else if (this.lastSplitPaneSize <= 0 || availableSize == this.lastSplitPaneSize || !BasicSplitPaneUI.this.painted || (dimension != null && this.getSizeForPrimaryAxis(dimension) != this.sizes[2])) {
                if (dimension != null) {
                    this.sizes[2] = this.getSizeForPrimaryAxis(dimension);
                }
                else {
                    this.sizes[2] = 0;
                }
                this.setDividerLocation(dividerLocation - sizeForPrimaryAxis, availableSize);
                BasicSplitPaneUI.this.dividerLocationIsSet = false;
            }
            else if (availableSize != this.lastSplitPaneSize) {
                this.distributeSpace(availableSize - this.lastSplitPaneSize, BasicSplitPaneUI.access$600(BasicSplitPaneUI.this));
            }
            this.doReset = false;
            BasicSplitPaneUI.this.dividerLocationIsSet = false;
            this.lastSplitPaneSize = availableSize;
            int initialLocation = this.getInitialLocation(insets);
            int i = 0;
            while (i < 3) {
                if (this.components[i] != null && this.components[i].isVisible()) {
                    this.setComponentToSize(this.components[i], this.sizes[i], initialLocation, insets, size);
                    initialLocation += this.sizes[i];
                }
                switch (i) {
                    case 0: {
                        i = 2;
                        continue;
                    }
                    case 2: {
                        i = 1;
                        continue;
                    }
                    case 1: {
                        i = 3;
                        continue;
                    }
                }
            }
            if (BasicSplitPaneUI.this.painted) {
                int dividerLocation2 = BasicSplitPaneUI.this.getDividerLocation(BasicSplitPaneUI.this.splitPane);
                if (dividerLocation2 != dividerLocation - sizeForPrimaryAxis) {
                    int lastDividerLocation = BasicSplitPaneUI.this.splitPane.getLastDividerLocation();
                    BasicSplitPaneUI.this.ignoreDividerLocationChange = true;
                    try {
                        BasicSplitPaneUI.this.splitPane.setDividerLocation(dividerLocation2);
                        BasicSplitPaneUI.this.splitPane.setLastDividerLocation(lastDividerLocation);
                    }
                    finally {
                        BasicSplitPaneUI.this.ignoreDividerLocationChange = false;
                    }
                }
            }
            return;
        }
        
        @Override
        public void addLayoutComponent(String str, Component component) {
            boolean n = true;
            if (str != null) {
                if (str.equals("divider")) {
                    this.components[2] = component;
                    this.sizes[2] = this.getSizeForPrimaryAxis(component.getPreferredSize());
                }
                else if (str.equals("left") || str.equals("top")) {
                    this.components[0] = component;
                    this.sizes[0] = 0;
                }
                else if (str.equals("right") || str.equals("bottom")) {
                    this.components[1] = component;
                    this.sizes[1] = 0;
                }
                else if (!str.equals("nonContinuousDivider")) {
                    n = false;
                }
            }
            else {
                n = false;
            }
            if (n == 0) {
                throw new IllegalArgumentException("cannot add to layout: unknown constraint: " + str);
            }
            this.doReset = true;
            return;
        }
        
        @Override
        public Dimension minimumLayoutSize(Container container) {
            int n = 0;
            int n2 = 0;
            Insets insets = BasicSplitPaneUI.this.splitPane.getInsets();
            for (int i = 0; i < 3; ++i) {
                if (this.components[i] != null) {
                    Dimension minimumSize = this.components[i].getMinimumSize();
                    int sizeForSecondaryAxis = this.getSizeForSecondaryAxis(minimumSize);
                    n += this.getSizeForPrimaryAxis(minimumSize);
                    if (sizeForSecondaryAxis > n2) {
                        n2 = sizeForSecondaryAxis;
                    }
                }
            }
            if (insets != null) {
                n += this.getSizeForPrimaryAxis(insets, true) + this.getSizeForPrimaryAxis(insets, false);
                n2 += this.getSizeForSecondaryAxis(insets, true) + this.getSizeForSecondaryAxis(insets, false);
            }
            if (this.axis == 0) {
                return new Dimension(n, n2);
            }
            return new Dimension(n2, n);
        }
        
        @Override
        public Dimension preferredLayoutSize(Container container) {
            int n = 0;
            int n2 = 0;
            Insets insets = BasicSplitPaneUI.this.splitPane.getInsets();
            for (int i = 0; i < 3; ++i) {
                if (this.components[i] != null) {
                    Dimension preferredSize = this.components[i].getPreferredSize();
                    int sizeForSecondaryAxis = this.getSizeForSecondaryAxis(preferredSize);
                    n += this.getSizeForPrimaryAxis(preferredSize);
                    if (sizeForSecondaryAxis > n2) {
                        n2 = sizeForSecondaryAxis;
                    }
                }
            }
            if (insets != null) {
                n += this.getSizeForPrimaryAxis(insets, true) + this.getSizeForPrimaryAxis(insets, false);
                n2 += this.getSizeForSecondaryAxis(insets, true) + this.getSizeForSecondaryAxis(insets, false);
            }
            if (this.axis == 0) {
                return new Dimension(n, n2);
            }
            return new Dimension(n2, n);
        }
        
        @Override
        public void removeLayoutComponent(Component component) {
            for (int i = 0; i < 3; ++i) {
                if (this.components[i] == component) {
                    this.components[i] = null;
                    this.sizes[i] = 0;
                    this.doReset = true;
                }
            }
        }
        
        @Override
        public void addLayoutComponent(Component component, Object o) {
            if (o == null || o instanceof String) {
                this.addLayoutComponent((String)o, component);
                return;
            }
            throw new IllegalArgumentException("cannot add to layout: constraint must be a string (or null)");
        }
        
        @Override
        public float getLayoutAlignmentX(Container container) {
            return 0.0f;
        }
        
        @Override
        public float getLayoutAlignmentY(Container container) {
            return 0.0f;
        }
        
        @Override
        public void invalidateLayout(Container container) {
        }
        
        @Override
        public Dimension maximumLayoutSize(Container container) {
            return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
        }
        
        public void resetToPreferredSizes() {
            this.doReset = true;
        }
        
        protected void resetSizeAt(int n) {
            this.sizes[n] = 0;
            this.doReset = true;
        }
        
        protected void setSizes(int[] array) {
            System.arraycopy(array, 0, this.sizes, 0, 3);
        }
        
        protected int[] getSizes() {
            int[] array = new int[3];
            System.arraycopy(this.sizes, 0, array, 0, 3);
            return array;
        }
        
        protected int getPreferredSizeOfComponent(Component component) {
            return this.getSizeForPrimaryAxis(component.getPreferredSize());
        }
        
        int getMinimumSizeOfComponent(Component component) {
            return this.getSizeForPrimaryAxis(component.getMinimumSize());
        }
        
        protected int getSizeOfComponent(Component component) {
            return this.getSizeForPrimaryAxis(component.getSize());
        }
        
        protected int getAvailableSize(Dimension dimension, Insets insets) {
            if (insets == null) {
                return this.getSizeForPrimaryAxis(dimension);
            }
            return this.getSizeForPrimaryAxis(dimension) - (this.getSizeForPrimaryAxis(insets, true) + this.getSizeForPrimaryAxis(insets, false));
        }
        
        protected int getInitialLocation(Insets insets) {
            if (insets != null) {
                return this.getSizeForPrimaryAxis(insets, true);
            }
            return 0;
        }
        
        protected void setComponentToSize(Component component, int n, int n2, Insets insets, Dimension dimension) {
            if (insets != null) {
                if (this.axis == 0) {
                    component.setBounds(n2, insets.top, n, dimension.height - (insets.top + insets.bottom));
                }
                else {
                    component.setBounds(insets.left, n2, dimension.width - (insets.left + insets.right), n);
                }
            }
            else if (this.axis == 0) {
                component.setBounds(n2, 0, n, dimension.height);
            }
            else {
                component.setBounds(0, n2, dimension.width, n);
            }
        }
        
        int getSizeForPrimaryAxis(Dimension dimension) {
            if (this.axis == 0) {
                return dimension.width;
            }
            return dimension.height;
        }
        
        int getSizeForSecondaryAxis(Dimension dimension) {
            if (this.axis == 0) {
                return dimension.height;
            }
            return dimension.width;
        }
        
        int getSizeForPrimaryAxis(Insets insets, boolean b) {
            if (this.axis == 0) {
                if (b) {
                    return insets.left;
                }
                return insets.right;
            }
            else {
                if (b) {
                    return insets.top;
                }
                return insets.bottom;
            }
        }
        
        int getSizeForSecondaryAxis(Insets insets, boolean b) {
            if (this.axis == 0) {
                if (b) {
                    return insets.top;
                }
                return insets.bottom;
            }
            else {
                if (b) {
                    return insets.left;
                }
                return insets.right;
            }
        }
        
        protected void updateComponents() {
            Component leftComponent = BasicSplitPaneUI.this.splitPane.getLeftComponent();
            if (this.components[0] != leftComponent) {
                if ((this.components[0] = leftComponent) == null) {
                    this.sizes[0] = 0;
                }
                else {
                    this.sizes[0] = -1;
                }
            }
            Component rightComponent = BasicSplitPaneUI.this.splitPane.getRightComponent();
            if (this.components[1] != rightComponent) {
                if ((this.components[1] = rightComponent) == null) {
                    this.sizes[1] = 0;
                }
                else {
                    this.sizes[1] = -1;
                }
            }
            Component[] components = BasicSplitPaneUI.this.splitPane.getComponents();
            Component component = this.components[2];
            this.components[2] = null;
            int i = components.length - 1;
            while (i >= 0) {
                if (components[i] != this.components[0] && components[i] != this.components[1] && components[i] != BasicSplitPaneUI.this.nonContinuousLayoutDivider) {
                    if (component != components[i]) {
                        this.components[2] = components[i];
                        break;
                    }
                    this.components[2] = component;
                    break;
                }
                else {
                    --i;
                }
            }
            if (this.components[2] == null) {
                this.sizes[2] = 0;
            }
            else {
                this.sizes[2] = this.getSizeForPrimaryAxis(this.components[2].getPreferredSize());
            }
        }
        
        void setDividerLocation(int max, int b) {
            int n = this.components[0] != null && this.components[0].isVisible();
            int n2 = this.components[1] != null && this.components[1].isVisible();
            int n3 = this.components[2] != null && this.components[2].isVisible();
            if (!(n3 == 0)) {
                b -= this.sizes[2];
            }
            max = Math.max(0, Math.min(max, b));
            if (!(n == 0)) {
                if (!(n2 == 0)) {
                    this.sizes[0] = max;
                    this.sizes[1] = b - max;
                }
                else {
                    this.sizes[0] = b;
                    this.sizes[1] = 0;
                }
            }
            else if (!(n2 == 0)) {
                this.sizes[1] = b;
                this.sizes[0] = 0;
            }
        }
        
        int[] getPreferredSizes() {
            int[] array = new int[3];
            for (int i = 0; i < 3; ++i) {
                if (this.components[i] != null && this.components[i].isVisible()) {
                    array[i] = this.getPreferredSizeOfComponent(this.components[i]);
                }
                else {
                    array[i] = -1;
                }
            }
            return array;
        }
        
        int[] getMinimumSizes() {
            int[] array = new int[3];
            for (int i = 0; i < 2; ++i) {
                if (this.components[i] != null && this.components[i].isVisible()) {
                    array[i] = this.getMinimumSizeOfComponent(this.components[i]);
                }
                else {
                    array[i] = -1;
                }
            }
            array[2] = ((this.components[2] != null) ? this.getMinimumSizeOfComponent(this.components[2]) : -1);
            return array;
        }
        
        void resetToPreferredSizes(int n) {
            int[] sizes = this.getPreferredSizes();
            int n2 = 0;
            for (int i = 0; i < 3; ++i) {
                if (sizes[i] != -1) {
                    n2 += sizes[i];
                }
            }
            if (n2 > n) {
                sizes = this.getMinimumSizes();
                n2 = 0;
                for (int j = 0; j < 3; ++j) {
                    if (sizes[j] != -1) {
                        n2 += sizes[j];
                    }
                }
            }
            this.setSizes(sizes);
            this.distributeSpace(n - n2, false);
        }
        
        void distributeSpace(int n, boolean b) {
            int n2 = this.components[0] != null && this.components[0].isVisible();
            int n3 = this.components[1] != null && this.components[1].isVisible();
            if (b) {
                if (n2 != 0 && this.getSizeForPrimaryAxis(this.components[0].getSize()) == 0) {
                    n2 = 0;
                    if (n3 != 0 && this.getSizeForPrimaryAxis(this.components[1].getSize()) == 0) {
                        n2 = 1;
                    }
                }
                else if (n3 != 0 && this.getSizeForPrimaryAxis(this.components[1].getSize()) == 0) {
                    n3 = 0;
                }
            }
            if (n2 != 0 && n3 != 0) {
                int n4 = (int)(BasicSplitPaneUI.this.splitPane.getResizeWeight() * (double)n);
                int n5 = n - n4;
                int[] sizes = this.sizes;
                int n6 = 0;
                sizes[n6] += n4;
                int[] sizes2 = this.sizes;
                int n7 = 1;
                sizes2[n7] += n5;
                int minimumSizeOfComponent = this.getMinimumSizeOfComponent(this.components[0]);
                int minimumSizeOfComponent2 = this.getMinimumSizeOfComponent(this.components[1]);
                int n8 = this.sizes[0] >= minimumSizeOfComponent;
                int n9 = this.sizes[1] >= minimumSizeOfComponent2;
                if (n8 == 0 && n9 == 0) {
                    if (this.sizes[0] < 0) {
                        int[] sizes8 = this.sizes;
                        int n15 = 1;
                        sizes8[n15] += this.sizes[0];
                        this.sizes[0] = 0;
                    }
                    else if (this.sizes[1] < 0) {
                        int[] sizes7 = this.sizes;
                        int n14 = 0;
                        sizes7[n14] += this.sizes[1];
                        this.sizes[1] = 0;
                    }
                }
                else if (n8 == 0) {
                    if (this.sizes[1] - (minimumSizeOfComponent - this.sizes[0]) < minimumSizeOfComponent2) {
                        if (this.sizes[0] < 0) {
                            int[] sizes6 = this.sizes;
                            int n13 = 1;
                            sizes6[n13] += this.sizes[0];
                            this.sizes[0] = 0;
                        }
                    }
                    else {
                        int[] sizes5 = this.sizes;
                        int n12 = 1;
                        sizes5[n12] -= minimumSizeOfComponent - this.sizes[0];
                        this.sizes[0] = minimumSizeOfComponent;
                    }
                }
                else if (n9 == 0) {
                    if (this.sizes[0] - (minimumSizeOfComponent2 - this.sizes[1]) < minimumSizeOfComponent) {
                        if (this.sizes[1] < 0) {
                            int[] sizes4 = this.sizes;
                            int n11 = 0;
                            sizes4[n11] += this.sizes[1];
                            this.sizes[1] = 0;
                        }
                    }
                    else {
                        int[] sizes3 = this.sizes;
                        int n10 = 0;
                        sizes3[n10] -= minimumSizeOfComponent2 - this.sizes[1];
                        this.sizes[1] = minimumSizeOfComponent2;
                    }
                }
                if (this.sizes[0] < 0) {
                    this.sizes[0] = 0;
                }
                if (this.sizes[1] < 0) {
                    this.sizes[1] = 0;
                }
            }
            else if (n2 != 0) {
                this.sizes[0] = Math.max(0, this.sizes[0] + n);
            }
            else if (n3 != 0) {
                this.sizes[1] = Math.max(0, this.sizes[1] + n);
            }
        }
    }
    
    public class BasicVerticalLayoutManager extends BasicSplitPaneUI.BasicHorizontalLayoutManager
    {
        public BasicVerticalLayoutManager() {
            super(1);
        }
    }
    
    private class Handler implements FocusListener, PropertyChangeListener
    {
        @Override
        public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
            if (propertyChangeEvent.getSource() == BasicSplitPaneUI.this.splitPane) {
                String propertyName = propertyChangeEvent.getPropertyName();
                if (propertyName == "orientation") {
                    BasicSplitPaneUI.this.orientation = BasicSplitPaneUI.this.splitPane.getOrientation();
                    BasicSplitPaneUI.this.resetLayoutManager();
                }
                else if (propertyName == "continuousLayout") {
                    BasicSplitPaneUI.this.setContinuousLayout(BasicSplitPaneUI.this.splitPane.isContinuousLayout());
                    if (!BasicSplitPaneUI.this.isContinuousLayout()) {
                        if (BasicSplitPaneUI.this.nonContinuousLayoutDivider == null) {
                            BasicSplitPaneUI.this.setNonContinuousLayoutDivider(BasicSplitPaneUI.this.createDefaultNonContinuousLayoutDivider(), true);
                        }
                        else if (BasicSplitPaneUI.this.nonContinuousLayoutDivider.getParent() == null) {
                            BasicSplitPaneUI.this.setNonContinuousLayoutDivider(BasicSplitPaneUI.this.nonContinuousLayoutDivider, true);
                        }
                    }
                }
                else if (propertyName == "dividerSize") {
                    BasicSplitPaneUI.this.divider.setDividerSize(BasicSplitPaneUI.this.splitPane.getDividerSize());
                    BasicSplitPaneUI.this.dividerSize = BasicSplitPaneUI.this.divider.getDividerSize();
                    BasicSplitPaneUI.this.splitPane.revalidate();
                    BasicSplitPaneUI.this.splitPane.repaint();
                }
            }
        }
        
        @Override
        public void focusGained(FocusEvent focusEvent) {
            BasicSplitPaneUI.this.dividerKeyboardResize = true;
            BasicSplitPaneUI.this.splitPane.repaint();
        }
        
        @Override
        public void focusLost(FocusEvent focusEvent) {
            BasicSplitPaneUI.this.dividerKeyboardResize = false;
            BasicSplitPaneUI.this.splitPane.repaint();
        }
    }
    
    private static class Actions extends UIAction
    {
        private static final String NEGATIVE_INCREMENT = "negativeIncrement";
        private static final String POSITIVE_INCREMENT = "positiveIncrement";
        private static final String SELECT_MIN = "selectMin";
        private static final String SELECT_MAX = "selectMax";
        private static final String START_RESIZE = "startResize";
        private static final String TOGGLE_FOCUS = "toggleFocus";
        private static final String FOCUS_OUT_FORWARD = "focusOutForward";
        private static final String FOCUS_OUT_BACKWARD = "focusOutBackward";
        
        Actions(String name) {
            super(name);
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            JSplitPane comp = (JSplitPane)actionEvent.getSource();
            BasicSplitPaneUI basicSplitPaneUI = (BasicSplitPaneUI)BasicLookAndFeel.getUIOfType(comp.getUI(), BasicSplitPaneUI.class);
            if (basicSplitPaneUI == null) {
                return;
            }
            String name = this.getName();
            if (name == "negativeIncrement") {
                if (basicSplitPaneUI.dividerKeyboardResize) {
                    comp.setDividerLocation(Math.max(0, basicSplitPaneUI.getDividerLocation(comp) - basicSplitPaneUI.getKeyboardMoveIncrement()));
                }
            }
            else if (name == "positiveIncrement") {
                if (basicSplitPaneUI.dividerKeyboardResize) {
                    comp.setDividerLocation(basicSplitPaneUI.getDividerLocation(comp) + basicSplitPaneUI.getKeyboardMoveIncrement());
                }
            }
            else if (name == "selectMin") {
                if (basicSplitPaneUI.dividerKeyboardResize) {
                    comp.setDividerLocation(0);
                }
            }
            else if (name == "selectMax") {
                if (basicSplitPaneUI.dividerKeyboardResize) {
                    Insets insets = comp.getInsets();
                    int n = (insets != null) ? insets.bottom : 0;
                    int n2 = (insets != null) ? insets.right : 0;
                    if (basicSplitPaneUI.orientation == 0) {
                        comp.setDividerLocation(comp.getHeight() - n);
                    }
                    else {
                        comp.setDividerLocation(comp.getWidth() - n2);
                    }
                }
            }
            else if (name == "startResize") {
                if (!basicSplitPaneUI.dividerKeyboardResize) {
                    comp.requestFocus();
                }
                else {
                    JSplitPane splitPane = (JSplitPane)SwingUtilities.getAncestorOfClass(JSplitPane.class, comp);
                    if (splitPane != null) {
                        splitPane.requestFocus();
                    }
                }
            }
            else if (name == "toggleFocus") {
                this.toggleFocus(comp);
            }
            else if (name == "focusOutForward") {
                this.moveFocus(comp, 1);
            }
            else if (name == "focusOutBackward") {
                this.moveFocus(comp, -1);
            }
            return;
        }
        
        private void moveFocus(JSplitPane splitPane, int n) {
            Container focusCycleRootAncestor = splitPane.getFocusCycleRootAncestor();
            FocusTraversalPolicy focusTraversalPolicy = focusCycleRootAncestor.getFocusTraversalPolicy();
            Component c = (n > 0) ? focusTraversalPolicy.getComponentAfter(focusCycleRootAncestor, splitPane) : focusTraversalPolicy.getComponentBefore(focusCycleRootAncestor, splitPane);
            HashSet<Component> set = new HashSet();
            if (splitPane.isAncestorOf(c)) {
                do {
                    set.add(c);
                    Container focusCycleRootAncestor2 = c.getFocusCycleRootAncestor();
                    FocusTraversalPolicy focusTraversalPolicy2 = focusCycleRootAncestor2.getFocusTraversalPolicy();
                    c = ((n > 0) ? focusTraversalPolicy2.getComponentAfter(focusCycleRootAncestor2, c) : focusTraversalPolicy2.getComponentBefore(focusCycleRootAncestor2, c));
                } while (splitPane.isAncestorOf(c) && !set.contains(c));
            }
            if (c != null && !splitPane.isAncestorOf(c)) {
                c.requestFocus();
            }
        }
        
        private void toggleFocus(JSplitPane splitPane) {
            Component leftComponent = splitPane.getLeftComponent();
            Component rightComponent = splitPane.getRightComponent();
            Component focusOwner = KeyboardFocusManager.getCurrentKeyboardFocusManager().getFocusOwner();
            Component nextSide = this.getNextSide(splitPane, focusOwner);
            if (nextSide != null) {
                if (focusOwner != null && ((SwingUtilities.isDescendingFrom(focusOwner, leftComponent) && SwingUtilities.isDescendingFrom(nextSide, leftComponent)) || (SwingUtilities.isDescendingFrom(focusOwner, rightComponent) && SwingUtilities.isDescendingFrom(nextSide, rightComponent)))) {
                    return;
                }
                SwingUtilities2.compositeRequestFocus(nextSide);
            }
        }
        
        private Component getNextSide(JSplitPane comp, Component a) {
            Component leftComponent = comp.getLeftComponent();
            Component rightComponent = comp.getRightComponent();
            if (a != null && SwingUtilities.isDescendingFrom(a, leftComponent) && rightComponent != null) {
                Component firstAvailableComponent = this.getFirstAvailableComponent(rightComponent);
                if (firstAvailableComponent != null) {
                    return firstAvailableComponent;
                }
            }
            JSplitPane splitPane = (JSplitPane)SwingUtilities.getAncestorOfClass(JSplitPane.class, comp);
            Component component;
            if (splitPane != null) {
                component = this.getNextSide(splitPane, a);
            }
            else {
                component = this.getFirstAvailableComponent(leftComponent);
                if (component == null) {
                    component = this.getFirstAvailableComponent(rightComponent);
                }
            }
            return component;
        }
        
        private Component getFirstAvailableComponent(Component firstAvailableComponent) {
            if (firstAvailableComponent != null && firstAvailableComponent instanceof JSplitPane) {
                JSplitPane splitPane = (JSplitPane)firstAvailableComponent;
                Component firstAvailableComponent2 = this.getFirstAvailableComponent(splitPane.getLeftComponent());
                if (firstAvailableComponent2 != null) {
                    firstAvailableComponent = firstAvailableComponent2;
                }
                else {
                    firstAvailableComponent = this.getFirstAvailableComponent(splitPane.getRightComponent());
                }
            }
            return firstAvailableComponent;
        }
    }
}
